@@ -30,9 +30,6 @@ export {EmulateX11WindowType};
 
 const appID = 'com.desktop.ding';
 const appPath = GLib.build_filenamev(['/', ...appID.split('.')]);
-const isWayland = typeof Meta.is_wayland_compositor === 'function'
-    ? Meta.is_wayland_compositor()
-    : true;
 
 class ManageWindow {
     /* This class is added to each managed window, and it's used to make it
@@ -59,7 +56,10 @@ class ManageWindow {
     */
 
     constructor(window, waylandClient, changedStatusCB) {
-        this._isX11 = !isWayland;
+        this.isWayland = typeof Meta.is_wayland_compositor === 'function'
+            ? Meta.is_wayland_compositor()
+            : true;
+        this._isX11 = !this.isWayland;
         this._waylandClient = waylandClient;
         this._window = window;
         this._signalIDs = [];
@@ -564,10 +564,13 @@ var EmulateX11WindowType = class {
      "addWindowManagedCustomJS_ding" method. That's all.
      */
     constructor() {
-        this._isX11 = !isWayland;
         this._windowList = new Set();
         this._overviewHiding = true;
         this._waylandClient = null;
+        this.isWayland = typeof Meta.is_wayland_compositor === 'function'
+            ? Meta.is_wayland_compositor()
+            : true;
+        this._isX11 = !this.isWayland;
     }
 
     set_wayland_client(client) {
